@@ -4,7 +4,9 @@
 # Adapts to operating system and allows configuation of codec
 # Urs Utzinger
 # 
-# 2022 Added access to more opencv camera properties, auto populate missing configs
+# 2022 Added access to more opencv camera properties
+#      Auto populates missing configs
+#      Access to opencv camera configs window
 # 2021 Initialize, Remove direct Frame acces (use only queue)
 # 2019 Initial release, based on Bitbuckets FRC 4183 code
 ###############################################################################
@@ -52,7 +54,7 @@ class cv2Capture(Thread):
             self._camera_res = res
         else: 
             if 'camera_res' in configs: self._camera_res   = configs['camera_res']
-            else:                       self._camera_res   = (320, 240)
+            else:                       self._camera_res   = (640, 480)
         if 'output_res' in configs:     self._output_res   = configs['output_res']
         else:                           self._output_res   = (-1,-1)
         if 'fps' in configs:            self._framerate    = configs['fps']
@@ -71,6 +73,8 @@ class cv2Capture(Thread):
         else:                           self._wbtemp       = -1
         if 'autowb' in configs:         self._autowb       = configs['autowb']
         else:                           self._autowb       = -1
+        if 'settings' in configs:       self._settings     = configs['settings']
+        else:                           self._settings     = -1
 
         self._output_width   = self._output_res[0]
         self._output_height  = self._output_res[1]
@@ -192,6 +196,8 @@ class cv2Capture(Thread):
             self.gain          = self._gain            # camera gain
             self.wbtemperature = self._wbtemp          # camera white balance temperature
             self.autowb        = self._autowb          # camera enable auto white balance
+
+            if self._settings > -1: self.cam.set(cv2.CAP_PROP_SETTINGS, 0.0) # open camera settings window
             
             # Update records
             self._camera_res    = self.resolution
@@ -207,6 +213,15 @@ class cv2Capture(Thread):
         else:
             if not self.log.full(): self.log.put_nowait((logging.CRITICAL, "CV2:Failed to open camera!"))
 
+    # Open Settings Window
+    ############################################################################
+    def opensettings(self):
+        """
+        Open up the camera settings window
+        """
+        if self.cam_open:
+            self.cam.set(cv2.CAP_PROP_SETTINGS, 0.0)
+
     # Camera routines #################################################
     # Reading and setting camera options
     ###################################################################
@@ -275,7 +290,7 @@ class cv2Capture(Thread):
                 self.width  = int(val)
                 self.height = int(val)
             self._camera_res = (int(self.cam.get(cv2.CAP_PROP_FRAME_WIDTH)), int(self.cam.get(cv2.CAP_PROP_FRAME_HEIGHT)))
-            if not self.log.full(): self.log.put_nowait((logging.ERROR, "CV2:Resolution:{}x{}".format(self._camera_res[0],self._camera_res[1])))
+            if not self.log.full(): self.log.put_nowait((logging.INFO, "CV2:Resolution:{}x{}".format(self._camera_res[0],self._camera_res[1])))
         else: # camera not open
             if not self.log.full(): self.log.put_nowait((logging.CRITICAL, "CV2:Failed to set Resolution, camera not open!"))
 
