@@ -142,7 +142,10 @@ if __name__ == '__main__':
             last_display = current_time
             key = cv2.waitKey(1) 
             if (key == 27) or (key & 0xFF == ord('q')): stop = True
-            if cv2.getWindowProperty("AVI", 0) < 0: stop = True
+            try:
+                cv2.getWindowProperty("AVI", 0) < 0
+            except:
+                stop = True
 
             if not avi.queue.full(): avi.queue.put_nowait((current_time, frame))
 
