@@ -17,7 +17,6 @@ import logging, time
 # TIFF
 import tifffile
 
-
 ###############################################################################
 # TIFF Storage Server
 ###############################################################################
@@ -29,12 +28,16 @@ class tiffServer(Thread):
 
     # Initialize the storage Thread
     # Opens Capture Device
-    def __init__(self, filename = None):
+    def __init__(self, filename = None, compression='PACKBITS', workers=None):
+        # compression = 'LZW', 'LZMA', 'ZSTD', 'JPEG', 'PACKBITS', 'NONE', 'LERC'
+        # compression ='jpeg', 'png', 'zlib'
 
         # Threading Queue, Locks, Events
         self.queue           = Queue(maxsize=32)
         self.log             = Queue(maxsize=32)
         self.stopped         = True
+        self.compression     = compression
+        self.workers         = workers
 
         # Initialize TIFF
         if filename is not None:
@@ -74,12 +77,9 @@ class tiffServer(Thread):
 
         while not self.stopped:
             (cube_time, data_cube) = self.queue.get(block=True, timeout=None)
-            self.tiff.write(data_cube, compression='PACKBITS', photometric='MINISBLACK', contiguous=False, metadata ={'time': cube_time, 'author': 'camera'} )
-            # compression = 'LZW', 'LZMA', 'ZSTD', 'JPEG', 'PACKBITS', 'NONE', 'LERC'
-            # compression ='jpeg', 'png', 'zlib'
+            self.tiff.write(data_cube, compression=self.compression, photometric='MINISBLACK', contiguous=False, metadata ={'time': cube_time, 'author': 'camera'}, maxworkers=self.workers )
             num_cubes += 1
 
-
             # Storage througput calculation
             current_time = time.time()
             if (current_time - last_time) >= 5.0: # framearray rate every 5 secs
@@ -99,7 +99,7 @@ if __name__ == '__main__':
     display_interval =  0.01
     height =540
     width = 720
-    depth = 3 # can display only 3 colors ;-)
+    depth = 3 # can display only 3 colors ;-) but this works with more than 3 dimensions also
 
     logging.basicConfig(level=logging.DEBUG)
     logger = logging.getLogger("TIFF")
@@ -107,12 +107,13 @@ if __name__ == '__main__':
     # Setting up Storage
     now = datetime.now()
     filename = now.strftime("%Y%m%d%H%M%S") + ".hdf5"
-    tiff = tiffServer("C:\\temp\\" + filename)
+    tiff = tiffServer("C:\\temp\\" + filename, compression='NONE')
     logger.log(logging.DEBUG, "Starting TIFF Server")
     tiff.start()
 
     # synthetic image
     image = np.random.randint(0, 255, (depth, height, width), 'uint8') 
+    frame = np.zeros((height, width, depth), 'uint8') 
 
     window_handle = cv2.namedWindow("TIFF", cv2.WINDOW_AUTOSIZE)
     font          = cv2.FONT_HERSHEY_SIMPLEX
@@ -123,7 +124,7 @@ if __name__ == '__main__':
 
     last_display = time.time()
     num_frames = 0
-    stop = False`
+    stop = False
     while(not stop):
         current_time = time.time()
 
@@ -133,15 +134,20 @@ if __name__ == '__main__':
 
         if (current_time - last_display) > display_interval:
             last_display = current_time
-            frame = image[1,:,:].copy()
+            frame[:,:,0] = image[0,:,:]
+            frame[:,:,1] = image[1,:,:]
+            frame[:,:,2] = image[2,:,:]
             cv2.putText(frame,"Frame:{}".format(num_frames), textLocation, font, fontScale, fontColor, lineType)
             cv2.imshow('TIFF', frame)
             num_frames += 1
             key = cv2.waitKey(1) 
-            if (key == 27) or (key & 0xFF == ord('q')): stop = False
-            if cv2.getWindowProperty("TIFF", 0) < 0: stop = False
+            if (key == 27) or (key & 0xFF == ord('q')): stop = True
+            try: 
+                cv2.getWindowProperty("TIFF", 0) < 0
+            except: 
+                stop = True
 
-            if not tiff.queue.full(): queue.put_nowait((current_time, image))
+            if not tiff.queue.full(): tiff.queue.put_nowait((current_time, image))
 
 
     tiff.stop()
