@@ -6,10 +6,25 @@
 ##########################################################################
 # Results
 # =======
-#   35-45 cubes per second with libtiff onto SSD
-#   13    cubes per second without libtiff onton SSD
-#   20-23 cubes per second with libtiff onto NVME
+# - 1 Crucuial MX300
+# - 2 Samsung PM991
+# - 3 WD SN850
+#   13    cubes per second libtiff 2022.5.4 on 1,2,3
+#   57    cubes per second libtiff 2021.10.12 on 1
+#   20-23 cubes per second libtiff 2021.10.12 on 2
+#
+#   12    cubes per second libtiff 2022.5.4 on 3 with maxworkers=1
+#   13    cubes per second libtiff 2022.5.4 on 3
+#   12    cubes per second libtiff 2022.3.25 on 3
+#   12    cubes per second libtiff 2022.3.16 on 3
+#   52    cubes per second libtiff 2022.2.9 on 3
+#   48    cubes per second libtiff 2022.2.2 on 3
+#   48    cubes per second libtiff 2021.11.2 on 3
+#   48    cubes per second libtiff 2021.10.12 on 3
+#   48    cubes per second libtiff 2021.10.10 on 3
+#   20    cubes per second libtiff 2020.12.8 on 3
 ##########################################################################
+
 import logging
 import time
 import numpy as np
@@ -31,7 +46,7 @@ now = datetime.now()
 filename = now.strftime("%Y%m%d%H%M%S") + ".tiff"
 from camera.streamer.tiffstorageserver import tiffServer
 logger.log(logging.INFO, "Settingup Storage Server")
-tiff = tiffServer("C:\\temp\\" + filename)
+tiff = tiffServer("C:\\temp\\" + filename, compression='NONE') # can also use PACKBITS which might result in 38% smaller files
 logger.log(logging.INFO, "Starting Storage Server")
 tiff.start()
 
